***********************************************
**** 5.1.do
***********************************************
**** This do file illustrates some basic within 
**** estimators
***********************************************
* log using "C:\program_evaluation\survey_paper\Paper\Dec12\STATA_do_files\5\5.1\logs\log.log", replace
log using "C:\program_evaluation\survey_paper\Paper\Dec13\STATA_do_files\5\5.1\log.log", replace
clear
clear matrix 
clear mata
set maxvar 5500
set matsize 5500
set mo off

set seed 2468
loc T=3
display c(seed)

* setting the observations to 300

set obs 5000

* drawing an individual ID variable

g ID=_n

* drawing the key variables from 
* a pseudo-random standard normal
* distribution
generate x_0=1
generate x_2=2*invnorm(uniform())

generate mu=2*invnorm(uniform())

* creating 2 observations per person

expand `T'

* new number of observations

di _N

by ID, sort: generate tt=_n
g t=tt-1
ta t
generate x_1=2*invnorm(uniform())
generate epsilony=3*invnorm(uniform())
generate epsilonc=3*invnorm(uniform())

loc y10=4
loc y11=1.5
loc y12=2
loc y13=3
loc y00=2
loc y01=1.5
loc y02=2
loc y03=3
loc c0=1
loc c1=1.5
loc c2=-1
g z=1
g y0=mu+epsilony
g y1=mu+epsilony
g c=mu+epsilonc
loc j=0
while (`j'<3){
replace y0=y0+`y0`j''*x_`j'
replace y1=y1+`y1`j''*x_`j'
replace c=c+`c`j''*x_`j'
loc j=`j'+1
}
replace y0=y0+`y03'*t
replace y1=y1+`y13'*t


g P=(y1-y0-c>0)


g TE=y1-y0
su TE

g Y=P*y1+(1-P)*y0


by ID, sort: egen avgP=mean(P)
* Basic summary statistics
tab P
ta avgP
by P, sort: summarize Y y1 y0 c x* epsilon*





* Basic summary statistics: participation
tab P
ta avgP if t==0


* Basic summary statistics: variable means

by P, sort: summarize Y y1 y0 c x* mu epsilon*



* Correlations among unobservables

corr P mu epsilony epsilonc


* Cross sectional regression
reg Y P x_1 x_2 t



* Cross sectional regression, first time period only
reg Y P x_1 x_2  if t==0


* Cross sectional regression, second time period only
reg Y P x_1 x_2 if t==1



sort ID t
g x_1_1=.
replace x_1_1=x_1[_n+1] if tt<`T'
g Y_1=.
replace Y_1=Y[_n+1] if tt<`T'
g P_1=.
replace P_1=P[_n+1] if tt<`T'

g deltaY=Y_1-Y
g deltaP=P_1-P
g deltax_1=x_1_1-x_1

* The basic first differenced regression
reg deltaY deltaP deltax_1 if tt<`T'


xtset ID t

xtivreg Y P x_1 (t=z), fd reg


by ID, sort: egen mY=mean(Y)
by ID, sort: egen mP=mean(P)
by ID, sort: egen mx_1=mean(x_1)
by ID, sort: egen mt=mean(t)

g ydot=Y-mY
g Pdot=P-mP
g x_1dot=x_1-mx_1
g t_dot=t-mt


* Simple demeaned fixed effects with no time trend
reg ydot Pdot x_1dot


* Simple demeaned fixed effects with no time trend or constant
reg ydot Pdot x_1dot, nocon

* Simple demeaned fixed effects with time trend
reg ydot  Pdot x_1dot t_dot, nocons

* Simple demeaned fixed effects with time trend
reg ydot  Pdot x_1dot t_dot

xtset ID 

xtreg Y P x_1, fe 


* STATA Xtreg, no time covariate 
xtreg Y P x_1, fe



xtreg Y P x_1 t, fe 

xtset ID 
* STATA Xtreg, time covariate
xtreg Y P x_1 t, fe


xtreg Y P x_1 x_2 t, fe

reg Y P x_1 x_2 t mu


* The correct specification of the original model
reg Y P x_1 x_2 t mu


* The correct specification of the original model and correct standard errors
reg Y P x_1 x_2 t mu, cluster(ID)


reg Y P x_1 t i.ID, nocons


* The dummy variable fixed effects model

reg Y P x_1 t i.ID


xtreg Y P x_1 x_2 t, fe
estimates store f1



xtreg Y P x_1 x_2 t, re
estimates store r1



hausman f1 r1, equations(1:1)

log close
