***********************************************
**** 6.1.do
***********************************************
**** This do file illustrates some basic IV 
**** estimators
***********************************************
* log using "C:\program_evaluation\survey_paper\Paper\Dec12\STATA_do_files\6\6.1\logs\log.log", replace
clear
clear matrix 
clear mata

set mo off

set seed 2468
display c(seed)

set obs 10000

* drawing an individual ID variable

* drawing the key variables from 
* a pseudo-random standard normal
* distribution
generate x0=1
generate x=2*invnorm(uniform())
generate z1=2*invnorm(uniform())
generate z2=2*invnorm(uniform())
generate mu=2*invnorm(uniform())
generate epsilony=3*invnorm(uniform())
generate epsilonc=3*invnorm(uniform())

loc y10=4
loc y11=2
loc y00=2
loc y01=2
loc c0=1
loc c1=1.5
loc c2=-.5
loc c3=.5
g y0=mu+epsilony
g y1=mu+epsilony

replace y0=y0+`y00'*x0
replace y1=y1+`y10'*x0
replace y0=y0+`y01'*x
replace y1=y1+`y11'*x

g c=mu+epsilonc
replace c=c+`c0'*x0
replace c=c+`c1'*x
replace c=c+`c2'*z1
replace c=c+`c3'*z2


g P=(y1-y0-c>0)

ta P

g TE=y1-y0
su TE

g Y=P*y1+(1-P)*y0

logit P x z1
logit P x z2
logit P x z1 z2
test z1 z2
reg P x z1 z2
test z1 z2




* Basic summary statistics: participation
tab P


* Basic summary statistics: variable means

by P, sort: summarize Y y1 y0 c x* z* mu epsilon*


* Correlations among unobservables

corr P z* mu epsilony epsilonc 


* Cross sectional regression
reg Y P x

* Manual two stage least squares with a single instrument


* First stage of ``manual'' two-stage least squares, 
* single instrument case

reg P x z1

predict Phat


* Second stage of ``manual'' two-stage least squares, 
* single instrument case

reg Y Phat x 


* Two stage least squares: STATA command

ivregress 2sls Y x (P=x z1), first



* Two stage least squares: STATA command

ivregress gmm Y x (P=x z1), first



drop Phat


* First stage of ``manual'' two-stage least squares, 
* two instrument (over-identified) case

reg P x z1 z2

predict Phat


* Second stage of ``manual'' two-stage least squares, 
* two instrument (over-identified) case

reg Y Phat x


* Two stage least squares: STATA command

ivregress 2sls Y x (P=x z1 z2), first


* Two stage least squares: STATA command

ivregress gmm Y x (P=x z1 z2), first


* GMM manual setup

global XB "{b0}"
global XB "$XB - {b1}*P"
global XB "$XB - {b2}*x"
 
gmm (Y-$XB), instruments(x z1 z2) vce(r)



etregress Y x, treat(P= x z1 z2)

etregress Y x, treat(P= x z1 z2) two


etregress Y x , treat(P= x z1 z2) two


etregress Y x , treat(P= x ) two


* First stage of ``manual'' two-stage least squares, 
* over-identified case
* instrument significance test

reg P x z1 z2

test z1 z2


* First stage of ``manual'' two-stage least squares, 
* two instrument (over-identified) case
* instrument significance test

logit P x z1 z2

test z1 z2


* A "consistent" model

ivregress 2sls Y x (P=x z1 z2)

estimates store c1


* An "efficient" model

reg Y P x

estimates store e1


* Hausman test

hausman c1 e1, equations(1:1)


* A "consistent" model

ivregress 2sls Y x (P=x z1 ), first

estimates store c2


* An "efficient" model

ivregress 2sls Y x (P=x z1 z2), first

estimates store e2


* Hausman test

hausman c2 e2, equations(1:1)


* Gmm estimation

ivregress gmm Y x (P=x z1 z2), first

* The Hansen test

estat overid


