***********************************************
**** 6.2.do
***********************************************
**** This do file illustrates some basic non- 
**** linear IV estimators
***********************************************
* log using "C:\program_evaluation\survey_paper\Paper\Dec12\STATA_do_files\6\6.2\logs\log.log", replace
clear
clear matrix 
clear mata

set mo off

set seed 2468
display c(seed)

set obs 10000

* drawing an individual ID variable

* drawing the key variables from 
* a pseudo-random standard normal
* distribution
generate x0=1
generate x=2*invnorm(uniform())
generate z1=2*invnorm(uniform())
generate z2=2*invnorm(uniform())
generate mu=2*invnorm(uniform())
generate epsilony=3*invnorm(uniform())
generate epsilonc=3*invnorm(uniform())

loc y10=4
loc y11=2
loc y00=2
loc y01=2
loc c0=1
loc c1=1.5
loc c2=-.5
loc c3=.5
g y0=mu+epsilony
g y1=mu+epsilony

replace y0=y0+`y00'*x0
replace y1=y1+`y10'*x0
replace y0=y0+`y01'*x
replace y1=y1+`y11'*x

g c=mu+epsilonc
replace c=c+`c0'*x0
replace c=c+`c1'*x
replace c=c+`c2'*z1
replace c=c+`c3'*z2


g P=(y1-y0-c>0)

ta P



replace y0=(y0>0)

replace y1=(y1>0)

g TE=y1-y0
su TE


by P, sort: ta y1 y0

g Y=P*y1+(1-P)*y0

logit P x z1
logit P x z2
logit P x z1 z2
test z1 z2
reg P x z1 z2
test z1 z2


* Basic summary statistics: participation
tab P

* Basic summary statistics: variable means

by P, sort: summarize Y y1 y0 c x* z* mu epsilon*



* Correlations among unobservables

corr P z* mu epsilony epsilonc 


* Cross sectional regression
reg Y P x


* Manual two stage least squares with a single instrument


* First stage of ``manual'' two-stage least squares, 
* single instrument case

reg P x z1

predict Phat


* Second stage of ``manual'' two-stage least squares, 
* single instrument case

reg Y Phat x 



* Two stage least squares: STATA command

ivregress 2sls Y x (P=x z1), first



* Two stage least squares: STATA command

ivregress gmm Y x (P=x z1), first


drop Phat


* First stage of ``manual'' two-stage least squares, 
* two instrument (over-identified) case

reg P x z1 z2

predict Phat

* Second stage of ``manual'' two-stage least squares, 
* two instrument (over-identified) case

reg Y Phat x



* Two stage least squares: STATA command

ivregress 2sls Y x (P=x z1 z2), first



* Two stage least squares: STATA command

ivregress gmm Y x (P=x z1 z2), first


* GMM manual setup

global XB "{b0}"
global XB "$XB - {b1}*P"
global XB "$XB - {b2}*x"
 
gmm (Y-$XB), instruments(x z1 z2) vce(r)



etregress Y x, treat(P= x z1 z2)


etregress Y x, treat(P= x z1 z2) two

etregress Y x, treat(P= x ) two


drop Phat

g Pt=P


* Basic Logit

logit Y P x

replace P=0

predict P0

replace P=1

predict P1

g mx= P1-P0

su mx


drop mx P0 P1

replace P=Pt


* Joint normality maximum likelihood

ivprobit Y x (P=x z1 z2)

replace P=0

predict P0, pr

replace P=1

predict P1, pr

g mx=P1-P0

su mx



drop mx P0 P1

replace P=Pt

g Pe=Pt

* First Stage, manual residual inclusion

reg P x z1 z2

predict Phat

g Pres=P-Phat


* Second stage, manual residual inclusion

probit Y P x Pres

replace P=0

predict P0

replace P=1

predict P1

g mx=P1-P0

su mx


drop mx P0 P1 Phat Pres

replace P=Pt

* Two step IV probit

ivprobit Y x (P=x z1 z2), twostep


* Biprobit

biprobit (Y= x P) (P=x z1 z2)

replace P=0

predict P0, pmarg1

replace P=1

predict P1, pmarg1

g mx=P1-P0

su mx


replace P=Pt

drop mx P1 P0 


biprobit (Y= x P z1 z2) (P=x z1 z2)

test [Y]z1 [Y]z2


replace P=0

predict P0, pmarg1

replace P=1

predict P1, pmarg1

g mx=P1-P0

su mx
replace P=Pt
g IDX=_n
g cons=1
keep IDX Y  P cons x z1 z2 
sa "C:\program_evaluation\survey_paper\Paper\Dec13\STATA_do_files\6\6.2\david_dfm.dta", replace


